Welcome to the **TheApix!** This library allows you to easily interact with the API using asynchronous options.

Installation

```sh
pip install TheApix
```

See the docs as [here](https://vivekkumar-in.github.io/TheApi/)
